@@ -176,7 +176,7 @@ def sign_collection_data(event, resources, to_review_enabled, **kwargs):
             if has_review_enabled:
                 # If preview collection: update and sign preview collection
                 updater.destination = resource["preview"]
-                updater.sign_and_update_destination(
+                changes_count = updater.sign_and_update_destination(
                     event.request,
                     source_attributes=new_collection,
                     next_source_status=STATUS.TO_REVIEW,
@@ -184,10 +184,14 @@ def sign_collection_data(event, resources, to_review_enabled, **kwargs):
             else:
                 # If no preview collection: just track `last_editor`
                 updater.update_source_review_request_by(event.request)
+                changes_count = None
             review_event_cls = signer_events.ReviewRequested
+            review_event_kw["changes_count"] = changes_count
+            review_event_kw["comment"] = new_collection.get("last_editor_comment", "")
 
         elif old_status == STATUS.TO_REVIEW and new_status == STATUS.WORK_IN_PROGRESS:
             review_event_cls = signer_events.ReviewRejected
+            review_event_kw["comment"] = new_collection.get("last_reviewer_comment", "")
 
         elif new_status == STATUS.TO_REFRESH:
             updater.refresh_signature(event.request, next_source_status=old_status)
@@ -230,8 +234,7 @@ def send_signer_events(event):
 def check_collection_status(
     event, resources, group_check_enabled, to_review_enabled, editors_group, reviewers_group
 ):
-    """Make sure status changes are allowed.
-    """
+    """Make sure status changes are allowed."""
     payload = event.payload
 
     current_user_id = event.request.prefixed_userid
@@ -346,6 +349,49 @@ def signer_impacts_resource(signer, bid, cid):
     return False
 
 
+def prevent_float_value(event, resources):
+    """This ResourceChanged event listener will reject records that
+    contain float values.
+
+    In order to be able to align our Canonical JSON implementation with
+    the most elaborated specification [0], we must forbid floats to be
+    introduced in the system.
+
+    This is indeed the only area where our implementation differs, and
+    instead of supporting complex migration paths, getting rid of floats
+    is the simplest approach. Floats can be published as strings if needed.
+
+    [0] https://github.com/gibson042/canonicaljson-spec
+    """
+
+    def scan(d, path=""):
+        for k, v in d.items():
+            path = f"{path}.{k}" if path else k
+            if isinstance(v, float):
+                raise ValueError(
+                    f"'{path}' field contains float value (tip: use integer or string)"
+                )
+            elif isinstance(v, dict):
+                scan(v, path)
+
+    # Only raise in configured resources.
+    resource, _ = pick_resource_and_signer(
+        event.request,
+        resources,
+        bucket_id=event.payload["bucket_id"],
+        collection_id=event.payload["collection_id"],
+    )
+    if resource is None:
+        return
+
+    # Check each created/updated record in the batch.
+    for impacted in event.impacted_objects:
+        try:
+            scan(impacted["new"])
+        except ValueError as e:
+            raise_invalid(message=str(e))
+
+
 def prevent_collection_delete(event, resources):
     request = event.request
     bid = event.payload["bucket_id"]
@@ -442,8 +488,7 @@ def prevent_collection_delete(event, resources):
 
 
 def check_collection_tracking(event, resources):
-    """Make sure tracking fields are not changed manually/removed.
-    """
+    """Make sure tracking fields are not changed manually/removed."""
     if event.request.prefixed_userid == PLUGIN_USERID:
         return
 
@@ -469,8 +514,7 @@ def check_collection_tracking(event, resources):
 
 
 def set_work_in_progress_status(event, resources):
-    """Put the status in work-in-progress if was signed.
-    """
+    """Put the status in work-in-progress if was signed."""
     resource, signer = pick_resource_and_signer(
         event.request,
         resources,
