@@ -250,7 +250,7 @@ class ForceReviewTest(SignoffWebTest, unittest.TestCase):
 
     def test_passing_from_signed_to_to_sign_is_allowed(self):
         """This is useful when the x5u certificate changed and you want
-           to retrigger a new signature."""
+        to retrigger a new signature."""
         self.app.patch_json(
             self.source_collection, {"data": {"status": "to-review"}}, headers=self.headers
         )
@@ -307,6 +307,45 @@ class RefreshSignatureTest(SignoffWebTest, unittest.TestCase):
         resp = self.app.get(self.source_collection, headers=self.headers)
         assert resp.json["data"]["status"] == "signed"
 
+    def test_resign_does_not_bump_destination_timestamp(self):
+        resp = self.app.head(self.destination_collection + "/records", headers=self.headers)
+        before = resp.headers["ETag"]
+
+        self.app.patch_json(
+            self.source_collection, {"data": {"status": "to-resign"}}, headers=self.headers
+        )
+
+        resp = self.app.head(self.destination_collection + "/records", headers=self.headers)
+        after = resp.headers["ETag"]
+        assert before == after
+
+    def test_request_review_and_re_sign_does_not_bump_destination_timestamp(self):
+        resp = self.app.head(self.destination_collection + "/records", headers=self.headers)
+        before = resp.headers["ETag"]
+
+        self.app.patch_json(
+            self.source_collection, {"data": {"status": "to-review"}}, headers=self.other_headers
+        )
+        self.app.patch_json(
+            self.source_collection, {"data": {"status": "to-sign"}}, headers=self.headers
+        )
+
+        resp = self.app.head(self.destination_collection + "/records", headers=self.headers)
+        after = resp.headers["ETag"]
+        assert before == after
+
+    def test_old_resign_does_not_bump_destination_timestamp(self):
+        resp = self.app.head(self.destination_collection + "/records", headers=self.headers)
+        before = resp.headers["ETag"]
+
+        self.app.patch_json(
+            self.source_collection, {"data": {"status": "to-sign"}}, headers=self.headers
+        )
+
+        resp = self.app.head(self.destination_collection + "/records", headers=self.headers)
+        after = resp.headers["ETag"]
+        assert before == after
+
     def test_editor_can_retrigger_a_signature(self):
         # Editor retriggers a signature, without going through review.
         self.app.patch_json(
@@ -617,8 +656,8 @@ class RollbackChangesTest(SignoffWebTest, unittest.TestCase):
             self.source_collection, {"data": {"status": "to-rollback"}}, headers=self.headers
         )
 
-        self.app.get(self.source_collection + f"/records/r1", headers=self.headers, status=404)
-        self.app.get(self.source_collection + f"/records/r2", headers=self.headers, status=404)
+        self.app.get(self.source_collection + "/records/r1", headers=self.headers, status=404)
+        self.app.get(self.source_collection + "/records/r2", headers=self.headers, status=404)
 
     def test_also_resets_changes_on_preview(self):
         resp = self.app.get(self.preview_collection + "/records", headers=self.headers)
@@ -661,7 +700,8 @@ class RollbackChangesTest(SignoffWebTest, unittest.TestCase):
         )
         # Delete r1.
         self.app.delete(
-            self.source_collection + "/records/r1", headers=self.headers,
+            self.source_collection + "/records/r1",
+            headers=self.headers,
         )
         # Approve deletion of r1.
         self.app.patch_json(
